# setup.py
from setuptools import setup, find_packages

setup(
    name="vish_print",
    version="0.1.0",
    description="An advanced print function with formatting and logging",
    author="Vishango",
    author_email="itsvishalhack@gmail.com",
    packages=find_packages(),
    install_requires=[],
    test_suite="tests",
)
